*************************************************************************
*
*	This file contains 3 FORTRAN 77 routines called in fit_gamm.r
*	This subroutines have been written for the R-interface of the
*	fit_gamm.f main programme since was not possible to directly
*	translate some of the commands.
*
*************************************************************************
      SUBROUTINE CHECKOBS(NSITES,RAIN,MISSFL,NOBS,P,COVS,MXPARAMS,
     +			SCRFN1,YY,MM,DD,ICHECK,MXNSITES)
*
*	Check if all required predictors are present and the rainfall 
*	is non-zero.
*	Write obs on scratch file number 1
*
*	Do not need to reset the paramters for MXPARAMS and MXNSITES
*	as they have been set in the main programme and passed through
*
      INTEGER NSITES,SCRFN1,NOBS,YY,MM,DD,P,ICHECK
      INTEGER MXPARAMS
      INTEGER MXNSITES, SITE
      INTEGER MISSFL(MXNSITES)
      DOUBLE PRECISION RAIN(MXNSITES)
      DOUBLE PRECISION COVS(MXNSITES,MXPARAMS)
*
*	X is not passed as an argument of the subroutine and cannot 
*	dimension it using passed arguments.
*	In Fortran90 can use 'dynamic arrays'
*
      DOUBLE PRECISION, ALLOCATABLE, DIMENSION (:) :: X 
*
*	Here, unlike Fortran77 i can dimesion exactly X, which is
*	of length P rather then give it a big dimension (0:MXPARAMS)
*
      ALLOCATE (X(P))
*
*      DATA SCRFN1 /85/ NO NEED IS PASSED FROM THE MAIN PROGRAMME
*
      DO 51 SITE=1,NSITES
       IF ((RAIN(SITE).GT.0.0D0).AND.(MISSFL(SITE).EQ.0)) THEN
	NOBS = NOBS + 1
	Y = RAIN(SITE)
	DO 52 J=1,P
	 X(J) = COVS(SITE,J)
 52     CONTINUE
*
*	Write this case to first scratch file, and flag to indicate no
*       further parameter checking is required. 
*
        WRITE(SCRFN1,REC=NOBS,ERR=920) SITE,YY,MM,DD,Y,(X(J),J=1,P)
        IF (ICHECK.EQ.0) ICHECK = 1
       ENDIF 
 51   CONTINUE

      DEALLOCATE (X)
*
*       Error trapping
*
 920  IF (NOBS.EQ.1) THEN
       WRITE(*,10)
      ELSE
       WRITE(*,11)
      ENDIF
      STOP

 10   FORMAT(/10X,59('*'),/10X,
     +'**** ERROR: In file fit_gamm.f, value of BYTELN is too ',
     +'****',/10X,
     +'**** small. Increase it and recompile (see file header ',
     +'****',/10X,
     +'**** for suggested values for your operating system).  ',
     +'****',/10X,59('*'))
 11   FORMAT(/10X,55('*'),/10X,
     +'**** ERROR: while writing to scratch file. You are ',
     +'****',/10X,
     +'**** probably out of disk space.                   ',
     +'****',/10X,55('*'))
      END

*************************************************************************
*************************************************************************
*************************************************************************
      SUBROUTINE RESFILE(FILENAME,CHAN65,NOBS,SCRFN2,SITE,YY,MM,DD,Y,MU,
     +				ETA,SCODES,MXPARAMS)
*
*	Write residual file
*
      INTEGER FILENAME
      INTEGER NOBS,SCRFN2,SITE,YY,MM,DD
      INTEGER MXPARAMS
      DOUBLE PRECISION MU,ETA
      CHARACTER*12 CHAN65
      CHARACTER*4, SCODES(MXPARAMS)
*
*      DATA CHAN65 /'res_gamm.dat'/
*
      OPEN(65,FILE=CHAN65)
      WRITE(65,7)
      DO 200 I=1,NOBS
       READ(SCRFN2,REC=I) SITE,YY,MM,DD,Y,MU,ETA
       WRITE(65,'(A4,1X,I4,T14,I2,T17,I3,T21,F8.4,T31,F8.4,T41,F8.4)')
     +   SCODES(SITE),YY,MM,DD,Y,MU,ETA
 200  CONTINUE

      CLOSE (65)
      CLOSE(SCRFN2)

      STOP

 7    FORMAT('SITE YEAR MONTH DAY OBSERVED PREDICTED    ETA')  

      END

*************************************************************************
*************************************************************************
*************************************************************************
      SUBROUTINE CLOSEFL(FLNAME)
*
*	Subroutine to close a file
*

      INTEGER FLNAME

      CLOSE(FLNAME)

      END