      BLOCK DATA PSINIT
*
*	Added July 1998 by R.Chandler, to initialise COMMON block
*	PSDATA.
*
      common /psdata/ lpsout,pscl,pxmin,pxmax,pymin,pymax,wxmin,
     +                wxmax,wymin,wymax
c
c Hardwire many of the plot parameters:
c
      data       lpsout/80/,pscl/0.24/,pxmin/0.0/,pxmax/288.0/
     +           pymin/0.0/,pymax/216.0/,wxmin/-10.0/,wxmax/60.0/,
     +           wymin/-10.0/,wymax/60.0/

      END
************************************************************************

        subroutine pltprob(ar1,nd,ar2,ilog,pmin,pmax,pinc,start,
     +             ncyc,hpxmin,hpxmax,hpymin,hpymax,title)
C%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
C                                                                      %
C Copyright (C) 1992 Stanford Center for Reservoir Forecasting.  All   %
C rights reserved.  Distributed with: C.V. Deutsch and A.G. Journel.   %
C ``GSLIB: Geostatistical Software Library and User's Guide,'' Oxford  %
C University Press, New York, 1992.                                    %
C                                                                      %
C The programs in GSLIB are distributed in the hope that they will be  %
C useful, but WITHOUT ANY WARRANTY.  No author or distributor accepts  %
C responsibility to anyone for the consequences of using them or for   %
C whether they serve any particular purpose or work at all, unless he  %
C says so in writing.  Everyone is granted permission to copy, modify  %
C and redistribute the programs in GSLIB, but only under the condition %
C that this notice and the above copyright notice remain intact.       %
C                                                                      %
C%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
c-----------------------------------------------------------------------
c
c                          Probability Plot
c                          ****************
c
c
c PARAMETERS:
c      ar1     The variable for the plot
c      nd      The number of data
c      ar2     A weight variable for each data
c      ilog    =0, then use arithmetic; =1, then use logarithmic
c      pmin    minimim limit for arithmetic scaling
c      pmax    maximum limit for arithmetic scaling
c      pinc    the labelliing increment
c      start   the starting value for log scaling (0.0001,0.001,0.01,..
c      ncyc    number of log (base 10) cycles
c      hpxmin  minimum X to use for plotting
c      hpxmax  maximum X to use for plotting
c      hpymin  minimum Y to use for plotting
c      hpymax  maximum Y to use for plotting
c
c
c
c AUTHOR: Clayton Deutsch                            DATE: November 1990
c-----------------------------------------------------------------------
      parameter(BIGNUM=99999999.,EPSLON=0.00001,ZERO=0.0,MAXTMP=5)
      dimension ar1(*),ar2(*)
      real      xx(MAXTMP),yy(MAXTMP),pval(21)
      character title*45
c
c Common variables for Postscript Plotting:
c
      common /psdata/ lpsout,pscl,pxmin,pxmax,pymin,pymax,wxmin,
     +                wxmax,wymin,wymax

      data       lin/1/
c
c The probability scaling and labelling:
c
      data      npval/21/,pval/0.0001,0.001,0.002,0.01,0.02,
     +          0.05,0.10,0.20,0.30,0.40,0.50,0.60,0.70,0.80,0.90,
     +          0.95,0.98,0.99,0.998,0.999,0.9999/
c
c Add a header:
c
      write(lpsout,998)
 998  format('%!PS',/,
     +'/m {moveto} def /l {lineto} def /r {rlineto} def',
     +' /s {stroke} def',/,
     +'/n {newpath} def /c {closepath} def /ltext{show} def',/,
     +'/rtext{ dup stringwidth pop -1 div 0  rmoveto show } def',/,
     +'/ltext{show} def',/,
     +'/ctext{ dup stringwidth pop -2 div 0  rmoveto show } def',/,
     +'/bullet{ 6 0 360 arc c fill } bind def',/,
     +' 108  234 translate',/,' 1.5 1.5 scale',/,
     +'%%EndProlog',/,
     +'2 setlinejoin ',/,
     +'0.240000 0.240000 scale')
c
c Sort the Data in Ascending Order:
c
      call sortem(1,1,nd,ar1,1,ar2,c,d,e,f,g,h)
c
c Get cumulative probability and normalize:
c
      ccdf = 0
      do 1 i=1,nd
 1    ccdf = ccdf + ar2(i)
      if(ccdf.lt.EPSLON) stop 'Cumulative Probability too LOW'
      oldcp = 0.0
      cp    = 0.0
      do 2 i=1,nd
            cp     = cp + ar2(i)/ccdf
            ar2(i) = 0.5*(cp+oldcp)
            oldcp  = cp
 2    continue
c
c Set some scaling parameters:
c
      if(ilog.eq.1) then
            pmin = alog10(start)
            pmax = alog10(start*(10.0**ncyc))
      else
            if(pmax.le.pmin) then
                  pmin = ar1(1)
                  pmax = ar1(nd)
                  pinc = (pmax-pmin)/10.0
            endif
      endif
      xhsmin = pmin
      xhsmax = pmax
      yhsmin = ginv(pval(1))
      yhsmax = ginv(pval(npval))
      xrange = hpxmax - hpxmin
      yrange = hpymax - hpymin
c
c Write the title and the labels:
c
      ts   = 7.5
      xloc = hpxmin - 0.15*xrange
      yloc = hpymin + 0.50*yrange
      call pstext(xloc,yloc,17,'Normal Percentile',ts,
     +                      1,90.0,1)
      xloc = hpxmin + 0.50*xrange
      yloc = hpymin - 0.15*yrange
      call pstext(xloc,yloc,14,'Residual value',ts,1,0.0,1)
      yloc = hpymax + 0.01*(hpxmax-hpxmin)
      call pstext(hpxmin,yloc,45,title,9.,3,0.,0)
c
c Draw a border box:
c
      xx(1) = hpxmin
      yy(1) = hpymin
      xx(2) = hpxmin
      yy(2) = hpymax
      xx(3) = hpxmax
      yy(3) = hpymax
      xx(4) = hpxmax
      yy(4) = hpymin
      xx(5) = hpxmin
      yy(5) = hpymin
      np    = 5
      siz   = 0.7
      idsh  = 0
      call psline(np,xx,yy,siz,idsh)
c
c Scale and Draw the Probability Axis:
c
      np    = 2
      siz   = 0.4
      xx(1) = hpxmin
      xx(2) = hpxmax
      xloc  = hpxmin - 0.01*xrange
      ts    = 7.0
      do 4 i=1,npval
            yloc  = ginv(pval(i))
            yy(1) = resc(yhsmin,yhsmax,hpymin,hpymax,yloc)
            yy(2) = yy(1)
            call psline(np,xx,yy,siz,idsh)
            yloc = yy(1) - 0.01*yrange
            cp   = pval(i) * 100.0
            write(title(1:5),'(i5)') int(cp)
            if(i.eq.1.or.i.eq.npval) write(title(1:5),'(f5.2)') cp
            if(i.eq.2.or.i.eq.3.or.i.eq.19.or.i.eq.20)
     +          write(title(1:5),'(f5.1)') cp
            call pstext(xloc,yloc,5,title,ts,1,0.0,2)
 4    continue
c
c Scale and Draw the Variable Axis:
c
      yy(1) = hpymin
      yy(2) = hpymax
      yloc  = hpymin - 0.05*xrange
      if(ilog.eq.1) then
c
c      LOGARITHMIC SCALE:
c
            start  = start / 10.0
            do 5 i=1,ncyc+1
                  start = start * 10.0
                  xloc = alog10(start)
                  xloc = resc(xhsmin,xhsmax,hpxmin,hpxmax,xloc)
                  a = abs(start)
                  s = start
                           write(title(1:8),'(f8.0)')s
                  if(a.lt.10) write(title(1:8),'(f8.1)')s
                  if(a.lt.1.) write(title(1:8),'(f8.2)')s
                  if(a.lt.0.1) write(title(1:8),'(f8.3)')s
                  if(a.lt.0.01) write(title(1:8),'(f8.4)')s
                  if(a.lt.0.001) write(title(1:8),'(f8.5)')s
                  if(a.lt.0.0001) write(title(1:8),'(f8.6)')s
                  if(a.lt.0.00001) write(title(1:8),'(f8.7)')s
                  call pstext(xloc,yloc,8,title,ts,1,0.0,1)
                  if(i.le.ncyc) then
                        do 6 j=1,9
                              xloc = alog10(start*j)
                              xx(1) = resc(xhsmin,xhsmax,
     +                                          hpxmin,hpxmax,xloc)
                              xx(2) = xx(1)
                              call psline(np,xx,yy,siz,idsh)
 6                      continue
                  endif
 5          continue
      else
c
c      ARITHMETIC SCALE:
c
            nloop = int((pmax-pmin)/pinc) + 1
            temp  = pmin-pinc
            do 7 i=1,nloop
                  temp = temp + pinc
                  xloc = resc(xhsmin,xhsmax,hpxmin,hpxmax,temp)
                  s = temp
                  a = abs(temp)
                           write(title(1:8),'(f8.0)')s
                  if(a.lt.10) write(title(1:8),'(f8.1)')s
                  if(a.lt.1.) write(title(1:8),'(f8.2)')s
                  if(a.lt.0.1) write(title(1:8),'(f8.3)')s
                  if(a.lt.0.01) write(title(1:8),'(f8.4)')s
                  if(a.lt.0.001) write(title(1:8),'(f8.5)')s
                  if(a.lt.0.0001) write(title(1:8),'(f8.6)')s
                  if(a.lt.0.00001) write(title(1:8),'(f8.7)')s
                  if(s.eq.0.0) write(title(1:8),'(f8.0)')s
                  call pstext(xloc,yloc,8,title,ts,1,0.0,1)
                  xx(1) = xloc
                  xx(2) = xx(1)
                  call psline(np,xx,yy,siz,idsh)
 7          continue
      endif
c
c Scale and Draw the points on the plot:
c
      do 10 i=1,nd
            if(ilog.eq.0) then
                  xloc  = ar1(i)
            else
                  if(ar1(i).le.EPSLON) go to 10
                  xloc  = alog10(ar1(i))
            endif
            yloc  = ginv(ar2(i))
            if(xloc.lt.xhsmin.or.xloc.gt.xhsmax.or.
     +         yloc.lt.yhsmin.or.yloc.gt.yhsmax) go to 10
            xx(1) = resc(xhsmin,xhsmax,hpxmin,hpxmax,xloc)
            yy(1) = resc(yhsmin,yhsmax,hpymin,hpymax,yloc)
            ix = int((resc(wxmin,wxmax,pxmin,pxmax,xx(1)))/ pscl)
            iy = int((resc(wymin,wymax,pymin,pymax,yy(1)))/ pscl)
            write(lpsout,101) ix,iy
 101        format('n ',i4.4,1x,i4.4,' bullet')
 10    continue
c
c Add a footer to the Postscript plot file:
c
      write(lpsout,999)
 999  format('%END OF PLOT',/,'4.166667 4.166667 scale',/,
     +       '%showpage',/,'%',/,'%',/,'%',/,
     +'0.66667 0.66667 scale',/,'-108 -234 translate',/,
     +'showpage')
c
c Return to Calling Program:
c
      return
      end



      subroutine sortem(iflag,ib,ie,a,iperm,b,c,d,e,f,g,h)
c-----------------------------------------------------------------------
c
c
c This is a subroutine for sorting a real array in ascending or
c  descending order. This routine is a translation into fortran iv
c  of algorithm 271, quickersort, by r.s. scowen in collected
c  algorithms of the acm. consult this for further references.
c
c The method is used is that of continually splitting the array
c  into parts such that all elements of one part are less than
c  all elements of the other, with a third part in the middle
c  consisting of one element. An element with value t is chosen 
c  arbitrarily (here we choose the  middle element). i and j give
c  the lower and upper limits of the segment being split. after 
c  the split a value q will have been found such that a(q)=t and
c  a(l)<=t<=a(m) for all i<=l<q<m<=j. the program then performs
c  operations on the two segments (i,q-1) and (q+1,j) as follows.
c  the smaller segment is split and the position of the larger
c  segment is stored in the lt and ut arrays. if the segment to
c  be split contains two or fewer elements, it is sorted and
c  another segment is obtained from the lt and ut arrays. when
c  no more segments remain, the array is completely sorted.
c
c
c INPUT PARAMETERS:
c
c    iflag  =1 ascending order,=0 decending order
c
c    a      =the array, a portion of which has to be sorted.
c
c    ib,ie  =the positions in array a of the first and last elements of 
c            the portion to be sorted.
c
c    iperm  =0 no other array is permuted.
c           =1 array b is permuted according to array a
c           =2 arrays b,c are permuted.
c           =3 arrays b,c,d are permuted.
c           =4 arrays b,c,d,e are permuted.
c           =5 arrays b,c,d,e,f are permuted.
c           =6 arrays b,c,d,e,f,g are permuted.
c           =7 arrays b,c,d,e,f,g,h are permuted.
c           >7 no other array is permuted.
c
c    b,c,d,e,f,g,h  =arrays to be permuted according to array a.
c
c OUTPUT PARAMETERS:
c
c    a      = the array, a portion of which has been sorted.
c
c    b,c,d,e,f,g,h  =arrays permuted according to array a (see iperm)
c
c NO EXTERNAL ROUTINES REQUIRED:
c
c Taken from G. Verly's MGLIB                         Revised: June 1989
c-----------------------------------------------------------------------
      dimension a(*),b(*),c(1),d(1),e(1),f(1),g(1),h(1)
      real ta,tb,tc,td,te,tf,tg,th,xa,xb,xc,xd,xe,xf,xg,xh
      integer   lt(25),ut(25),i,j,k,m,p,q
c
c       the dimensions for lt and ut have to be at least log  n.
c                                                           2
c       17 was chosen to handle n<131,073.
c
      j=ie
      m=1
      i=ib
      iring=iperm+1
      if (iperm.gt.7) iring=1
c
c if this segment has more than two elements  we split it
c
 10      if (j-i-1) 100,90,15
c
c p is the position of an arbitrary element in the segment
c we choose the middle element. under certain circumstances
c it may be advantageous to choose p at random.
c
 15      p=(j+i)/2
      ta=a(p)
      a(p)=a(i)
      go to (21,19,18,17,16,161,162,163),iring
 163      th=h(p)
      h(p)=h(i)
 162      tg=g(p)
      g(p)=g(i)
 161      tf=f(p)
      f(p)=f(i)
 16      te=e(p)
      e(p)=e(i)
 17      td=d(p)
      d(p)=d(i)
 18      tc=c(p)
      c(p)=c(i)
 19      tb=b(p)
      b(p)=b(i)
 21      continue
c
c Starting at the beginning of the segment, search for k
c such that a(k)>t
c
      q=j
      k=i
 20      k=k+1
c
c Modification so that we can sort ascending or decending:
c
      if (k.gt.q) go to 60
      if(iflag.eq.1) then
            if (a(k).le.ta) go to 20
      else
            if (a(k).ge.ta) go to 20
      endif
c
c Such an element has now been found now search for a q such that
c a(q)<t starting at the end of the segment.
c
 30      continue
      if(iflag.eq.1) then
            if (a(q).lt.ta) go to 40
      else
            if (a(q).gt.ta) go to 40
      endif
      q=q-1
      if (q.gt.k) go to 30
      go to 50
c
c a(q) has now been found. we interchange a(q) and a(k)
c
 40      xa=a(k)
      a(k)=a(q)
      a(q)=xa
      go to (45,44,43,42,41,411,412,413),iring
 413      xh=h(k)
      h(k)=h(q)
      h(q)=xh
 412      xg=g(k)
      g(k)=g(q)
      g(q)=xg
 411      xf=f(k)
      f(k)=f(q)
      f(q)=xf
 41      xe=e(k)
      e(k)=e(q)
      e(q)=xe
 42      xd=d(k)
      d(k)=d(q)
      d(q)=xd
 43      xc=c(k)
      c(k)=c(q)
      c(q)=xc
 44      xb=b(k)
      b(k)=b(q)
      b(q)=xb
 45      continue
c
c Update q and search for another pair to interchange:
c
      q=q-1
      go to 20
 50      q=k-1
 60      continue
c
c The upwards search has now met the downwards search:
c
      a(i)=a(q)
      a(q)=ta
      go to (65,64,63,62,61,611,612,613),iring
 613      h(i)=h(q)
      h(q)=th
 612      g(i)=g(q)
      g(q)=tg
 611      f(i)=f(q)
      f(q)=tf
 61      e(i)=e(q)
      e(q)=te
 62      d(i)=d(q)
      d(q)=td
 63      c(i)=c(q)
      c(q)=tc
 64      b(i)=b(q)
      b(q)=tb
 65      continue
c
c The segment is now divided in three parts: (i,q-1),(q),(q+1,j)
c store the position of the largest segment in lt and ut
c
      if (2*q.le.i+j) go to 70
        lt(m)=i
        ut(m)=q-1
        i=q+1
      go to 80
 70     lt(m)=q+1
        ut(m)=j
        j=q-1
c
c       update m and split the new smaller segment
 80   m=m+1
      go to 10
c
c       we arrive here if the segment has  two elements
c       we test to see if the segment is properly ordered
c       if not, we perform an interchange
c
c Modification:
c
 90      continue
      if(iflag.eq.1) then
            if (a(i).le.a(j)) go to 100
      else
            if (a(i).ge.a(j)) go to 100
      endif
      xa=a(i)
      a(i)=a(j)
      a(j)=xa
      go to (95,94,93,92,91,911,912,913),iring
 913  xh=h(i)
      h(i)=h(j)
      h(j)=xh
 912  xg=g(i)
      g(i)=g(j)
      g(j)=xg
 911  xf=f(i)
      f(i)=f(j)
      f(j)=xf
   91 xe=e(i)
      e(i)=e(j)
      e(j)=xe
   92 xd=d(i)
      d(i)=d(j)
      d(j)=xd
   93 xc=c(i)
      c(i)=c(j)
      c(j)=xc
   94 xb=b(i)
      b(i)=b(j)
      b(j)=xb
   95 continue
c
c       if lt and ut contain more segments to be sorted repeat process
 100  m=m-1
      if (m.le.0) goto 110
      i=lt(m)
      j=ut(m)
      go to 10
  110 continue
      return
      end



      subroutine pstext(xs,ys,lostr,str,tsiz,ifont,rot,iadj)
c-----------------------------------------------------------------------
c
c              Write Postscript Text commands to a file
c              ****************************************
c
c
c CALLING ARGUMENTS:
c
c  xs            starting value of x in the range xmin to xmax
c  ys            starting value of y in the range ymin to ymax
c  lostr      number of characters in str to print
c  str            the character string
c  tsiz            Text size in 1/72 of an inch
c  ifont      Font Number: See font number below
c  rot             Rotation Angle to post the text (default to 0.0)
c  iadj            Adjustment: 0=left adjusted, 1=centre, 2=right
c
c
c AUTHOR: C. Deutsch                                 DATE: November 1988
c-----------------------------------------------------------------------
      character str*80,fnnt(10)*32,line*132,size*4,part1*1,part2*7
c
c Common Block for Postscript Output Unit and Scaling:
c
        common /psdata/ lpsout,pscl,pxmin,pxmax,pymin,pymax,xmin,
     +                  xmax,ymin,ymax
        save      fnnt,ifold,tsold,izip
c
c Preset 10 different fonts:
c
        data fnnt/'/Helvetica             findfont ',
     +            '/Helvetica-Bold        findfont ',
     +            '/Helvetica-BoldOblique findfont ',
     +            '/Times-Roman           findfont ',
     +            '/Times-Bold            findfont ',
     +            '/Times-Italic          findfont ',
     +            '/Times-BoldItalic      findfont ',
     +            '/Courier               findfont ',
     +            '/Courier-Bold          findfont ',
     +            '/Courier-BoldOblique   findfont '/
      data ifold/0/,tsold/0.0/,izip/0/
      part1 = '('
      part2 = ')  text'
c
c Remove leading and trailing blanks:
c
      lost = lostr
      do 1 i=1,lostr
            if(str(1:1).eq.' ') then
                  lost = lost - 1
                  do 2 j=1,lost
                        k = j + 1
                        str(j:j) = str(k:k)
 2                continue
            else
                  go to 3
            endif
 1    continue
 3    continue
      k = lost
      do 4 i=1,k
            ix = k - i + 1
            if(str(ix:ix).ne.' ') go to 5
            lost = lost - 1
 4    continue
 5    if(lost.le.0) return
c
c Create line to set the text size and type:
c
      if(ifont.ne.ifold.or.tsiz.ne.tsold) then
            isiz=int(tsiz/pscl)
            write(size,'(i4)') isiz
            line=fnnt(ifont)//size//' scalefont setfont'      
            write(lpsout,'(a)')line(1:54)
            ifold = ifont
            tsold = tsiz
      endif
c
c Set the correct adjustment:
c
      part2(3:3) = 'l'
      if(iadj.eq.1) part2(3:3) = 'c'
      if(iadj.eq.2) part2(3:3) = 'r'
c
c Write the lines and position to the Postscript file:
c                  
      ix = int((resc(xmin,xmax,pxmin,pxmax,xs))/pscl)
      iy = int((resc(ymin,ymax,pymin,pymax,ys))/pscl)
c
c Rotate if Necessary: 
c
      line = part1//str(1:lost)//part2
      if(rot.ne.0.0) then
            irot = int(rot)
            write(lpsout,102) ix,iy
            write(lpsout,103) irot 
            write(lpsout,100) izip,izip
            write(lpsout,'(a)')line(1:lost+8)
            ix   = -1.0 * ix
            iy   = -1.0 * iy
            irot = -1.0 * irot
            write(lpsout,103) irot 
            write(lpsout,102) ix,iy
      else
c
c Just write out the text if no rotation:
c
            write(lpsout,100)ix,iy
            write(lpsout,'(a)')line(1:lost+8)
      endif
 100  format(i4.4,1x,i4.4,1x,'m')
 102  format(i5,1x,i5,1x,'translate')
 103  format(i5,1x,'rotate')
c
c Finished - Return to calling program:
c
      return
      end



      subroutine psline(np,x,y,lwidt,idsh)
c-----------------------------------------------------------------------
c
c              Write Postscript line commands to a file
c              ****************************************
c
c
c CALLING ARGUMENTS:
c
c  np        the number of points in the x and y array to join
c  x()       array of x values in the range xmin to xmax
c  y()       array of y values in the range ymin to ymax
c  lwidt     the width of the line (1.0 = dark, 0.5 = light)
c  idsh      dashing Index
c
c NOTES:
c
c  1. The pxmin,pxmax,.. variables are in the standard 1/72 inch 
c     resolution of the postscript page. If a different scale is 
c     going to be used in the printing set pscl to the scale.
c
c  2. If "idsh" is zero then no dashing is perfomed
c
c
c AUTHOR: C. Deutsch                                 DATE: November 1988
c-----------------------------------------------------------------------
      real      x(*),y(*),lwidt,lwold
      character dash(10)*24
c
c Common Block for Postscript Output Unit and Scaling:
c
      common /psdata/ lpsout,pscl,pxmin,pxmax,pymin,pymax,xmin,
     +                  xmax,ymin,ymax
      save      lwold
c
c Dash Patterns:
c
        data dash/'[40 20] 0 setdash       ',
     +            '[13 14 13 20] 0 setdash ',
     +            '[12 21 4 21] 0 setdash  ',
     +            '[10 10] 0 setdash       ',
     +            '[20 20] 0 setdash       ',
     +            '[30 30] 0 setdash       ',
     +            '[40 40] 0 setdash       ',
     +            '[50 50] 0 setdash       ',
     +            '[50 50] 0 setdash       ',
     +            '[50 50] 0 setdash       '/
c
c Change the line width if necessary:
c
      if(pscl.lt.0.01) pscl = 1.0
      if(idsh.gt.10)   idsh = 10 
      if(lwidt.ne.lwold) then
            width = lwidt/pscl
            write(lpsout,100) width
 100        format(f6.3,' setlinewidth')
            lwold = lwidt
      endif
c
c Start a new path and loop through the points:
c
      if(idsh.gt.0) write(lpsout,'(a24)') dash(idsh)
      write(lpsout,101)
 101  format('n')
      do 1 i=1,np
            ix = int(resc(xmin,xmax,pxmin,pxmax,x(i))/pscl)
            iy = int(resc(ymin,ymax,pymin,pymax,y(i))/pscl)
            if(i.eq.1) then
                  write(lpsout,102) ix,iy
 102              format(i4.4,1x,i4.4,' m')
            else
                  write(lpsout,103) ix,iy
 103              format(i4.4,1x,i4.4,' l')
            endif
 1    continue      
      write(lpsout,104)
 104  format('s')
      if(idsh.gt.0) write(lpsout,105)
 105  format('[] 0 setdash')
c
c Finished - Return to calling program:
c
      return
      end



      real function ginv(p)
c-----------------------------------------------------------------------
c
c Computes the inverse of the standard normal cumulative distribution
c function with a numerical approximation from : Abramovitz, M. and
c Stegun, I., 1972, handbook of mathematical functions, 10th printing,
c National Bureau of Standards, p. 933.
c
c-----------------------------------------------------------------------
c
c Coefficients of approximation:
c
      data c0/2.515517/,c1/.802853/,c2/.010328/
      data d1/1.432788/,d2/.189269/,d3/.001308/
c
c Values for + and - infinity:
c
      data gneg/-1e10/,gpos/1e10/
c
c Check for probability = 0 or 1
c
      if(p.le.0.0) then
            ginv = gneg
      else if(p.ge.1.0) then
            ginv = gpos
c
c Approximate the function:
c
      else
            pp = p
            if(pp.ge.0.5) pp = 1.0 - pp
            t    = sqrt(alog(1./(pp*pp)))
            t2   = t*t
            t3   = t2*t
            ginv = t - (c0+c1*t+c2*t2)/(1+d1*t+d2*t2+d3*t3)
            if(p.eq.pp) ginv=-ginv
      endif
c
c Return with ginv:
c
      return
      end



        real function resc(xmin1,xmax1,xmin2,xmax2,x111)
        rsc=(xmax2-xmin2)/(xmax1-xmin1)
        resc=xmin2 + (x111 - xmin1 ) * rsc
        return
        end
